Grant Jenks Tools
=================

`Grant Jenks`_ tools.

.. _`Grant Jenks`: http://www.grantjenks.com


Features
--------

- Pure-Python
- Developed on Python 2.7
- Tested on CPython 2.7

Quickstart
----------

Installing ``gj`` is simple with `pip <https://pip.pypa.io/en/stable/>`_::

  $ pip install gj

You can access documentation in the interpreter with Python's built-in help
function::

  >>> import gj
  >>> help(gj)

Reference and Indices
---------------------

* `GJ Documentation`_
* `GJ at PyPI`_
* `GJ at GitHub`_
* `GJ Issue Tracker`_

.. _`GJ Documentation`: http://www.grantjenks.com/docs/gj/
.. _`GJ at PyPI`: https://pypi.python.org/pypi/gj/
.. _`GJ at GitHub`: https://github.com/grantjenks/python-gj/
.. _`GJ Issue Tracker`: https://github.com/grantjenks/python-gj/issues/

License
-------

Copyright 2016 Grant Jenks

Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License.  You may obtain a copy of the
License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed
under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
CONDITIONS OF ANY KIND, either express or implied.  See the License for the
specific language governing permissions and limitations under the License.
